/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or (at
 *  your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *  MA 02110-1301, USA.
 *
 *  Copyright © 2006 Pierre Habouzit
 */

/*
 * Copyright notice from original mutt:
 * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
 *
 * This file is part of mutt-ng, see http://www.muttng.org/.
 * It's licensed under the GNU General Public License,
 * please see the file GPL in the top level source directory.
 */

#ifndef MUTT_LIB_LIB_BUFFER_H
#define MUTT_LIB_LIB_BUFFER_H

typedef struct {
    char *data;          /* pointer to data */
    char *dptr;          /* current read/write position */
    ssize_t dsize;       /* length of data */
    int destroy;         /* destroy `data' when done? */
} BUFFER;

BUFFER *mutt_buffer_init(BUFFER *);
void mutt_buffer_free(BUFFER **);

BUFFER *mutt_buffer_from(BUFFER *, const char *);
void mutt_buffer_add(BUFFER *, const char *, ssize_t);
static inline void mutt_buffer_addstr(BUFFER *b, const char *s) {
    mutt_buffer_add(b, s, m_strlen(s));
}

static inline void mutt_buffer_addch(BUFFER *b, char c) {
    mutt_buffer_add(b, &c, 1);
}

static inline void mutt_buffer_reset(BUFFER *b) {
    *(b->dptr = b->data) = '\0';
}

#endif /* MUTT_LIB_LIB_BUFFER_H */
